@@ -50,9 +50,10 @@ gs_popular_tile_get_app (GsPopularTile *tile)
 	return priv->app;
 }
 
-static void
-app_state_changed (GsApp *app, GParamSpec *pspec, GsPopularTile *tile)
+static gboolean
+app_state_changed_idle (gpointer user_data)
 {
+	GsPopularTile *tile = GS_POPULAR_TILE (user_data);
 	AtkObject *accessible;
 	GsPopularTilePrivate *priv;
 	GtkWidget *label;
@@ -63,13 +64,13 @@ app_state_changed (GsApp *app, GParamSpec *pspec, GsPopularTile *tile)
 	accessible = gtk_widget_get_accessible (GTK_WIDGET (tile));
 
 	label = gtk_bin_get_child (GTK_BIN (priv->eventbox));
-	switch (gs_app_get_state (app)) {
+	switch (gs_app_get_state (priv->app)) {
 	case AS_APP_STATE_INSTALLED:
 	case AS_APP_STATE_INSTALLING:
 	case AS_APP_STATE_REMOVING:
 		installed = TRUE;
 		name = g_strdup_printf ("%s (%s)",
-					gs_app_get_name (app),
+					gs_app_get_name (priv->app),
 					_("Installed"));
 		/* TRANSLATORS: this is the small blue label on the tile
 		 * that tells the user the application is installed */
@@ -78,7 +79,7 @@ app_state_changed (GsApp *app, GParamSpec *pspec, GsPopularTile *tile)
 	case AS_APP_STATE_UPDATABLE:
 		installed = TRUE;
 		name = g_strdup_printf ("%s (%s)",
-					gs_app_get_name (app),
+					gs_app_get_name (priv->app),
 					_("Updates"));
 		/* TRANSLATORS: this is the small blue label on the tile
 		 * that tells the user there is an update for the installed
@@ -88,7 +89,7 @@ app_state_changed (GsApp *app, GParamSpec *pspec, GsPopularTile *tile)
 	case AS_APP_STATE_AVAILABLE:
 	default:
 		installed = FALSE;
-		name = g_strdup (gs_app_get_name (app));
+		name = g_strdup (gs_app_get_name (priv->app));
 		break;
 	}
 
@@ -96,9 +97,18 @@ app_state_changed (GsApp *app, GParamSpec *pspec, GsPopularTile *tile)
 
 	if (GTK_IS_ACCESSIBLE (accessible)) {
 		atk_object_set_name (accessible, name);
-		atk_object_set_description (accessible, gs_app_get_summary (app));
+		atk_object_set_description (accessible, gs_app_get_summary (priv->app));
 	}
 	g_free (name);
+
+	g_object_unref (tile);
+	return G_SOURCE_REMOVE;
+}
+
+static void
+app_state_changed (GsApp *app, GParamSpec *pspec, GsPopularTile *tile)
+{
+	g_idle_add (app_state_changed_idle, g_object_ref (tile));
 }
 
 void
@@ -111,6 +121,9 @@ gs_popular_tile_set_app (GsPopularTile *tile, GsApp *app)
 
 	priv = gs_popular_tile_get_instance_private (tile);
 
+	if (priv->app)
+		g_signal_handlers_disconnect_by_func (priv->app, app_state_changed, tile);
+
 	g_clear_object (&priv->app);
 	if (!app)
 		return;
@@ -144,6 +157,9 @@ gs_popular_tile_destroy (GtkWidget *widget)
 
 	priv = gs_popular_tile_get_instance_private (tile);
 
+	if (priv->app)
+		g_signal_handlers_disconnect_by_func (priv->app, app_state_changed, tile);
+
 	g_clear_object (&priv->app);
 
 	GTK_WIDGET_CLASS (gs_popular_tile_parent_class)->destroy (widget);
