@@ -94,6 +94,7 @@ gs_shell_search_app_installed_cb (GObject *source,
 		if (!gs_shell_is_active (helper->shell_search->priv->shell))
 			gs_app_notify_installed (helper->app);
 	}
+	gs_shell_search_reload (helper->shell_search);
 	g_object_unref (helper->app);
 	g_object_unref (helper->shell_search);
 	g_free (helper);
@@ -124,6 +125,7 @@ gs_shell_search_app_removed_cb (GObject *source,
 					    error);
 		g_error_free (error);
 	}
+	gs_shell_search_reload (helper->shell_search);
 	g_object_unref (helper->app);
 	g_object_unref (helper->shell_search);
 	g_free (helper);
@@ -284,45 +286,26 @@ out: ;
 }
 
 /**
- * gs_shell_search_refresh:
- **/
-void
-gs_shell_search_refresh (GsShellSearch *shell_search, const gchar *value, gboolean scroll_up)
+ * gs_shell_search_load:
+ */
+static void
+gs_shell_search_load (GsShellSearch *shell_search)
 {
 	GsShellSearchPrivate *priv = shell_search->priv;
-	GtkWidget *widget;
-
-	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "buttonbox_main"));
-	gtk_widget_show (widget);
-
-	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "search_bar"));
-	gtk_widget_show (widget);
-
-        if (scroll_up) {
-                GtkAdjustment *adj;
-                adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (priv->scrolledwindow_search));
-                gtk_adjustment_set_value (adj, gtk_adjustment_get_lower (adj));
-        }
-        if (gs_shell_get_mode (priv->shell) == GS_SHELL_MODE_SEARCH) {
-                gs_grab_focus_when_mapped (priv->scrolledwindow_search);
-        }
-
-	if (g_strcmp0 (value, priv->value) == 0)
-		return;
-
-	g_free (priv->value);
-	priv->value = g_strdup (value);
 
 	/* remove old entries */
 	gs_container_remove_all (GTK_CONTAINER (priv->list_box_search));
 
 	/* cancel any pending searches */
-	g_cancellable_cancel (priv->search_cancellable);
-	g_cancellable_reset (priv->search_cancellable);
+	if (priv->search_cancellable != NULL) {
+		g_cancellable_cancel (priv->search_cancellable);
+		g_object_unref (priv->search_cancellable);
+	}
+	priv->search_cancellable = g_cancellable_new ();
 
 	/* search for apps */
 	gs_plugin_loader_search_async (priv->plugin_loader,
-				       value,
+				       priv->value,
 				       GS_PLUGIN_REFINE_FLAGS_DEFAULT |
 				       GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION |
 				       GS_PLUGIN_REFINE_FLAGS_REQUIRE_HISTORY |
@@ -337,6 +320,53 @@ gs_shell_search_refresh (GsShellSearch *shell_search, const gchar *value, gboole
 	gs_start_spinner (GTK_SPINNER (priv->spinner_search));
 }
 
+/**
+ * gs_shell_search_reload:
+ */
+void
+gs_shell_search_reload (GsShellSearch *shell_search)
+{
+	GsShellSearchPrivate *priv = shell_search->priv;
+	if (priv->value != NULL)
+		gs_shell_search_load (shell_search);
+}
+
+/**
+ * gs_shell_search_switch_to:
+ **/
+void
+gs_shell_search_switch_to (GsShellSearch *shell_search, const gchar *value, gboolean scroll_up)
+{
+	GsShellSearchPrivate *priv = shell_search->priv;
+	GtkWidget *widget;
+
+	if (gs_shell_get_mode (priv->shell) != GS_SHELL_MODE_SEARCH) {
+		g_warning ("Called switch_to(search) when in mode %s",
+			   gs_shell_get_mode_string (priv->shell));
+		return;
+	}
+
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "buttonbox_main"));
+	gtk_widget_show (widget);
+
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "search_bar"));
+	gtk_widget_show (widget);
+
+        if (scroll_up) {
+                GtkAdjustment *adj;
+                adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (priv->scrolledwindow_search));
+                gtk_adjustment_set_value (adj, gtk_adjustment_get_lower (adj));
+        }
+
+	if (g_strcmp0 (value, priv->value) == 0)
+		return;
+
+	g_free (priv->value);
+	priv->value = g_strdup (value);
+
+	gs_shell_search_load (shell_search);
+}
+
 /**
  * gs_shell_installed_sort_func:
  *
@@ -373,8 +403,11 @@ gs_shell_search_get_app_sort_key (GsApp *app)
 	desc = gs_app_get_description (app);
 	g_string_append_printf (key, "%c:", desc != NULL ? '2' : '1');
 
-	/* sort by rating */
-	rating = gs_app_get_rating (app);
+	/* sort by the search key */
+	g_string_append_printf (key, "%s:", gs_app_get_search_sort_key (app));
+
+	/* sort by kudos */
+	rating = gs_app_get_kudos_weight (app);
 	g_string_append_printf (key, "%03i:", rating > 0 ? rating : 0);
 
 	/* sort by length of description */
@@ -453,10 +486,8 @@ gs_shell_search_cancel_cb (GCancellable *cancellable,
 {
 	GsShellSearchPrivate *priv = shell_search->priv;
 
-	if (priv->search_cancellable != NULL) {
+	if (priv->search_cancellable != NULL)
 		g_cancellable_cancel (priv->search_cancellable);
-		g_clear_object (&priv->search_cancellable);
-	}
 }
 
 /**
@@ -524,7 +555,6 @@ gs_shell_search_init (GsShellSearch *shell_search)
 	shell_search->priv = gs_shell_search_get_instance_private (shell_search);
 	shell_search->priv->sizegroup_image = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	shell_search->priv->sizegroup_name = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	shell_search->priv->search_cancellable = g_cancellable_new ();
 }
 
 /**
@@ -543,10 +573,8 @@ gs_shell_search_finalize (GObject *object)
 	g_object_unref (priv->plugin_loader);
 	g_object_unref (priv->cancellable);
 
-	if (priv->search_cancellable != NULL) {
-		g_cancellable_cancel (priv->search_cancellable);
-		g_clear_object (&priv->search_cancellable);
-	}
+	if (priv->search_cancellable != NULL)
+		g_object_unref (priv->search_cancellable);
 
 	g_free (priv->value);
 
