@@ -101,6 +101,8 @@ out:
 gboolean
 gs_plugin_add_popular (GsPlugin *plugin,
 		       GList **list,
+		       const gchar *category,
+		       const gchar *category_exclude,
 		       GCancellable *cancellable,
 		       GError **error)
 {
@@ -122,7 +124,8 @@ gs_plugin_add_popular (GsPlugin *plugin,
 	} else {
 		apps = gs_moduleset_get_modules (plugin->priv->moduleset,
 						 GS_MODULESET_MODULE_KIND_APPLICATION,
-						 "popular");
+						 "popular",
+						 category);
 	}
 
 	/* just add all */
@@ -165,11 +168,12 @@ gs_plugin_refine (GsPlugin *plugin,
 	/* just mark each one as core */
 	apps = gs_moduleset_get_modules (plugin->priv->moduleset,
 					 GS_MODULESET_MODULE_KIND_APPLICATION,
-					 "system");
+					 "system",
+					 NULL);
 	for (l = *list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
 		for (i = 0; apps[i] != NULL; i++) {
-			if (g_strcmp0 (apps[i], gs_app_get_id_full (app)) == 0) {
+			if (g_strcmp0 (apps[i], gs_app_get_id (app)) == 0) {
 				gs_app_set_kind (app, GS_APP_KIND_SYSTEM);
 				break;
 			}
@@ -179,7 +183,8 @@ gs_plugin_refine (GsPlugin *plugin,
 	/* just mark each one as core */
 	pkgs = gs_moduleset_get_modules (plugin->priv->moduleset,
 					 GS_MODULESET_MODULE_KIND_PACKAGE,
-					 "core");
+					 "core",
+					 NULL);
 	for (l = *list; l != NULL; l = l->next) {
 		app = GS_APP (l->data);
 		for (i = 0; pkgs[i] != NULL; i++) {
